==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2107_155.zip: ronportal/controllers/monitorovaniv.php <==
<?php
/**
 * stanislav.elbl, 13.05.2020
 * Monitorovani vyroby
 */

namespace Ron\RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\Model;
use Ron\RonPortal\FotoOutputObject;
use Ron\RonPortal\NeniPravoException;
use Ron\RonPortal\PracovniPomer;
use Ron\RonPortal\Prava;
use Ron\StringUtils;
use Ron\TextManager;


class MonitorovaniVyrobyController extends JsonController
{
    /** @var Database */
    var $database;

    /**
     * MonitorovaniVyrobyController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param JsonOutputObject $output
     */
    function vlozPuvodni($output)
    {
        Prava::nastavObdobiProPrava(time());

        require_once 'vyroba/f_puvodnivyroba.php';

        $f = new VkladaniVyrobyFormular($this->database);
        if (!$f ->handleAction()) {
            $output ->addMessages(MessageManager::getInstance());
        }
    }


    /**
     * @param JsonOutputObject $output
     * @throws NeniPravoException
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    function loadDetailData($output)
    {
        require_once 'adsapp/ppomer.php';
        $pp = PracovniPomer::nactiPP($this ->database, (int)$_GET['idpp']);
        if (!Prava::lzeZobrazitPP('vyroba', $pp ->idPP)) {
            throw new NeniPravoException();
        }

        $params = $this ->database ->createParameters();
        $cursor = $this ->database ->getSqlResult(
            'SELECT PuvodniVyroba.DatumCas, PuvodniVyroba.KodVyrobniCinnosti, VyrobniCinnost.Popis, PuvodniVyroba.Terminal' .
            ' FROM PuvodniVyroba, VyrobniCinnost' .
            ' WHERE VyrobniCinnost.Kod = PuvodniVyroba.KodVyrobniCinnosti' .
            ' AND PuvodniVyroba.RC = ' . $params ->addParameter($pp ->rc) .
            ' AND PuvodniVyroba.OsobniCislo = ' . $params ->addParameter($pp ->osobniCislo) .
            ' AND PuvodniVyroba.DatumNastupu = ' . $params ->addParameter($this ->database ->dateToParam($pp ->datumNastupu)) .
            ' AND PuvodniVyroba.DatumCas >= ' . $params ->addParameter($this ->database ->dateToParam(DateUtils::incMinute(time(), -12 * 60))) .
            ' ORDER BY PuvodniVyroba.DatumCas',
            $params
        );

        $data = [];
        while ($row = $cursor ->fetch()) {
            $time = $this ->database ->stringToTimestamp($row[0]);
            $data[] = [
                'datum' => StringUtils::format('date', $time),
                'cas' => StringUtils::format('time', $time),
                'kodVyrobniCinnosti' => StringUtils::jsonText($row[1]),
                'popis' => StringUtils::jsonText($row[2]),
                'terminal' => StringUtils::jsonText($row[3])
            ];
        }

        $output ->addData('osobniCislo', StringUtils::jsonText($pp ->osobniCislo));
        $output ->addData('idPP', $pp ->idPP);
        if ($pp ->idFotografie) {
            $output->addData('idFotografie', $pp->idFotografie);
        }
        $output ->addData('puvodniVyroba', $data);

        $cursor ->close();
    }


    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'vlozpuvodni' :
                $this ->vlozPuvodni($output);
                break;

            case 'detaildata' :
                $this ->loadDetailData($output);
                break;

            default :
                throw new \Exception('Chyba v MonitorovaniVyrobyController: Neznama akce! (' . $_GET['action'] . ')');
        }
    }


    function foto()
    {
        require_once 'adsapp/fotoutils.php';

        $idpp = (int)$_GET['idpp'];

        Prava::nastavObdobiProPrava(time(), time());
        Prava::nactiPravaUzivatele($this ->database);

        if (!Prava::lzeZobrazitPP('vyroba', $idpp)) {
            throw new NeniPravoException();
        }

        $result = new FotoOutputObject($this->database);
        $result->nactiIdFotkyPracovnihoPomeru($_GET['idpp']);
        return $result;
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');
        TextManager::getInstance() ->loadStrings('vyroba.ini');

        Prava::nastavObdobiProPrava(time());
        Prava::nactiPravaUzivatele($this ->database);

        if (isset($_GET['action'])) {
            if ($_GET['action'] == "foto") {
                return $this ->foto();
            }

            return parent::handleAction($action);
        }

        HtmlHeaders::getInstance() ->addScript('script/vyroba.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');

        require_once 'vyroba/b_monitorovanivyroby.php';
        $b = new MonitorovaniVyrobyBrowser($this ->database);
        $b ->load();

        if ($b ->zobrazitVkladani) {
            require_once 'vyroba/f_puvodnivyroba.php';
            $f = new VkladaniVyrobyFormular($this->database);

            Model::addViewObject($f);
        }

        Model::addViewObject(new BaseViewObject('vyroba/view_detailmonitorovani.php'));

        return $b;
    }
}

return new MonitorovaniVyrobyController($this ->database);

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2302_169.zip: ronportal/controllers/monitorovaniv.php <==
<?php
/**
 * stanislav.elbl, 13.05.2020
 * Monitorovani vyroby
 */

namespace RonPortal\Vyroba;

use Ron\DateUtils;
use Ron\DB\Database;
use Ron\Http\HtmlHeaders;
use Ron\MessageManager;
use Ron\MVC\BaseViewObject;
use Ron\MVC\JsonController;
use Ron\MVC\JsonOutputObject;
use Ron\MVC\Model;
use Ron\StringUtils;
use Ron\TextManager;
use RonPortal\NeniPravoException;
use RonPortal\PracovniPomer;
use RonPortal\Prava;
use RonPortal\System\FotoOutputObject;


class MonitorovaniVyrobyController extends JsonController
{
    /** @var Database */
    var $database;

    /**
     * MonitorovaniVyrobyController constructor.
     * @param Database $database
     */
    public function __construct(Database $database)
    {
        $this->database = $database;
    }


    /**
     * @param JsonOutputObject $output
     */
    function vlozPuvodni($output)
    {
        Prava::nastavObdobiProPrava(time());

        $f = new VkladaniVyrobyFormular($this->database);
        if (!$f ->handleAction()) {
            $output ->addMessages(MessageManager::getInstance());
        }
    }


    /**
     * @param JsonOutputObject $output
     * @throws NeniPravoException
     * @throws \Exception
     * @throws \Ron\DB\DBException
     */
    function loadDetailData($output)
    {
        $pp = PracovniPomer::nactiPP($this ->database, (int)$_GET['idpp']);
        if (!Prava::lzeZobrazitPP('vyroba', $pp ->idPP)) {
            throw new NeniPravoException();
        }

        $params = $this ->database ->createParameters();
        $cursor = $this ->database ->getSqlResult(
            'SELECT PuvodniVyroba.DatumCas, PuvodniVyroba.KodVyrobniCinnosti, VyrobniCinnost.Popis, PuvodniVyroba.Terminal' .
            ' FROM PuvodniVyroba, VyrobniCinnost' .
            ' WHERE VyrobniCinnost.Kod = PuvodniVyroba.KodVyrobniCinnosti' .
            ' AND PuvodniVyroba.RC = ' . $params ->addParameter($pp ->rc) .
            ' AND PuvodniVyroba.OsobniCislo = ' . $params ->addParameter($pp ->osobniCislo) .
            ' AND PuvodniVyroba.DatumNastupu = ' . $params ->addParameter($this ->database ->dateToParam($pp ->datumNastupu)) .
            ' AND PuvodniVyroba.DatumCas >= ' . $params ->addParameter($this ->database ->dateToParam(DateUtils::incMinute(time(), -12 * 60))) .
            ' ORDER BY PuvodniVyroba.DatumCas',
            $params
        );

        $data = [];
        while ($row = $cursor ->fetch()) {
            $time = $this ->database ->stringToTimestamp($row[0]);
            $data[] = [
                'datum' => StringUtils::format('date', $time),
                'cas' => StringUtils::format('time', $time),
                'kodVyrobniCinnosti' => StringUtils::jsonText($row[1]),
                'popis' => StringUtils::jsonText($row[2]),
                'terminal' => StringUtils::jsonText($row[3])
            ];
        }

        $output ->addData('osobniCislo', StringUtils::jsonText($pp ->osobniCislo));
        $output ->addData('idPP', $pp ->idPP);
        if ($pp ->idFotografie) {
            $output->addData('idFotografie', $pp->idFotografie);
        }
        $output ->addData('puvodniVyroba', $data);

        $cursor ->close();
    }


    function handleJsonAction($action, $output)
    {
        switch ($_GET['action']) {
            case 'vlozpuvodni' :
                $this ->vlozPuvodni($output);
                break;

            case 'detaildata' :
                $this ->loadDetailData($output);
                break;

            default :
                throw new \Exception('Chyba v MonitorovaniVyrobyController: Neznama akce! (' . $_GET['action'] . ')');
        }
    }


    function foto()
    {
        $idpp = (int)$_GET['idpp'];

        Prava::nastavObdobiProPrava(time(), time());
        Prava::nactiPravaUzivatele($this ->database);

        if (!Prava::lzeZobrazitPP('vyroba', $idpp)) {
            throw new NeniPravoException();
        }

        $result = new FotoOutputObject($this->database);
        $result->nactiIdFotkyPracovnihoPomeru($_GET['idpp']);
        return $result;
    }


    public function handleAction($action)
    {
        TextManager::getInstance() ->loadStrings('dochazka.ini');
        TextManager::getInstance() ->loadStrings('vyroba.ini');

        Prava::nastavObdobiProPrava(time());
        Prava::nactiPravaUzivatele($this ->database);

        if (isset($_GET['action'])) {
            if ($_GET['action'] == "foto") {
                return $this ->foto();
            }

            return parent::handleAction($action);
        }

        HtmlHeaders::getInstance() ->addScript('script/vyroba.js');
        HtmlHeaders::getInstance() ->addCss('css/dochazka.css');

        $b = new MonitorovaniVyrobyBrowser($this ->database);
        $b ->load();

        if ($b ->zobrazitVkladani) {
            $f = new VkladaniVyrobyFormular($this->database);

            Model::addViewObject($f);
        }

        Model::addViewObject(new BaseViewObject('ronportal/vyroba/view_detail_monitorovani.php'));

        return $b;
    }
}

return new MonitorovaniVyrobyController($this ->database);
